==> environment_switch-0.0.4.tar.gz: lib/environment_switch.dart <==

import 'dart:async';
import 'package:flutter/material.dart';
import 'package:shared_preferences/shared_preferences.dart';
import 'package:flutter/services.dart';

class EnvironmentSwitch {
   static const MethodChannel _channel =
      const MethodChannel('environment_switch');

  static Future<String> get platformVersion async {
    final String version = await _channel.invokeMethod('getPlatformVersion');
    return version;
  }

    // 保存环境变量的key
  static final _envPrefsKey = "jf_environment_key";

  static SharedPreferences prefs;

  static var _clickedCount = 0;

  final _environments = ["测试环境", "预发环境", "线上环境", "其他", "取消"];

  static final _isProduct = const bool.fromEnvironment('dart.vm.product');

// main.dart 里优先调用
  static Future getInstance() async {
    prefs = await SharedPreferences.getInstance();
    _channel.invokeMethod("initSdk", {"env": getEnv()});
    if (_isProduct) {
      prefs.setString(_envPrefsKey, "2");
    }
  }

  EnvironmentSwitch.show(BuildContext context) {
    _clickedCount += 1;

    if (_clickedCount < 9) {
      Future.delayed(const Duration(seconds: 3), () {
        _clickedCount = 0;
      });
      return;
    }

    if (_clickedCount != 9) {
      return;
    }

    showModalBottomSheet(
        context: context,
        isDismissible: false,
        builder: (context) => BottomSheet(
              onClosing: () {},
              builder: (context) => ListView.builder(
                  itemCount: _environments.length,
                  itemBuilder: (context, index) => ListTile(
                        title: Text("${_environments[index]}"),
                        onTap: () {
                          if (_environments[index] != "取消") {
                            _saveEnv("$index");
                          } else {
                            Navigator.of(context).pop();
                          }
                          // print("-------  ${getEnv()}");
                        },
                      )),
            ));
  }

  void _saveEnv(String value) {
    prefs.setString(_envPrefsKey, value);
  }

  static String getEnv() {
    return prefs.getString(_envPrefsKey);
  }

}

==> environment_switch-0.0.5.tar.gz: lib/environment_switch.dart <==
import 'dart:async';
import 'package:flutter/material.dart';
import 'package:shared_preferences/shared_preferences.dart';
import 'package:flutter/services.dart';

class EnvironmentSwitch {

  static const MethodChannel _channel =
      const MethodChannel('environment_switch');

  // static Future<String> get platformVersion async {
  //   try {
  //     final String version = await _channel.invokeMethod('getPlatformVersion');
  //     return version;
  //   } on PlatformException catch (e) {} on MissingPluginException catch (e) {}
  // }

  // 保存环境变量的key
  static const _envPrefsKey = "jf_environment_key";

  static SharedPreferences prefs;

  static var _clickedCount = 0;

  final _environments = ["测试环境", "预发环境", "线上环境", "其他", "取消"];

  static final _isProduct = const bool.fromEnvironment('dart.vm.product');

// main.dart 里优先调用
  static Future getInstance() async {
    prefs = await SharedPreferences.getInstance();
    try {
      _channel.invokeMethod("initSdk", {"env": getEnv()});
      // if (_isProduct) {
      //   prefs.setString(_envPrefsKey, "2");
      // }
    } on PlatformException catch (e) {} on MissingPluginException catch (e) {}
  }

  EnvironmentSwitch.show(BuildContext context) {
    _clickedCount += 1;

    if (_clickedCount < 9) {
      Future.delayed(const Duration(seconds: 3), () {
        _clickedCount = 0;
      });
      return;
    }

    if (_clickedCount != 9) {
      return;
    }

    showModalBottomSheet(
        context: context,
        isDismissible: false,
        builder: (context) => BottomSheet(
              onClosing: () {},
              builder: (context) => ListView.builder(
                  itemCount: _environments.length,
                  itemBuilder: (context, index) => ListTile(
                        title: Text("${_environments[index]}"),
                        onTap: () {
                          if (_environments[index] != "取消") {
                            _saveEnv("$index");
                          } else {
                            Navigator.of(context).pop();
                          }
                          // print("-------  ${getEnv()}");
                        },
                      )),
            ));
  }

  void _saveEnv(String value) {
    prefs.setString(_envPrefsKey, value);
  }

  static String getEnv() {
    return prefs.getString(_envPrefsKey) ?? '2';
  }
}
